@@ -19,7 +19,6 @@ Configuration options registration and useful routines.
 """
 
 from oslo.config import cfg
-from keystoneclient.middleware import auth_token
 
 from mistral.openstack.common import log
 from mistral import version
@@ -30,8 +29,8 @@ api_opts = [
 ]
 
 engine_opts = [
-    cfg.StrOpt('engine', default='mistral.engine.scalable.engine',
-               help='Mistral engine class'),
+    cfg.StrOpt('engine', default='default',
+               help='Mistral engine plugin'),
     cfg.StrOpt('host', default='0.0.0.0',
                help='Name of the engine node. This can be an opaque '
                     'identifier. It is not necessarily a hostname, '
@@ -45,25 +44,19 @@ engine_opts = [
 pecan_opts = [
     cfg.StrOpt('root', default='mistral.api.controllers.root.RootController',
                help='Pecan root controller'),
-    cfg.ListOpt('modules', default=["mistral.api"]),
-    cfg.BoolOpt('debug', default=False),
-    cfg.BoolOpt('auth_enable', default=True)
+    cfg.ListOpt('modules', default=["mistral.api"],
+                help='A list of modules where pecan will search for '
+                     'applications.'),
+    cfg.BoolOpt('debug', default=False,
+                help='Enables the ability to display tracebacks in the '
+                     'browser and interactively debug during '
+                     'development.'),
+    cfg.BoolOpt('auth_enable', default=True,
+                help='Enables user authentication in pecan.')
 ]
 
 db_opts = [
-    # TODO: add DB properties.
-]
-
-rabbit_opts = [
-    cfg.StrOpt('rabbit_host', default='0.0.0.0',
-               help='RabbitMQ server host name'),
-    cfg.IntOpt('rabbit_port', default=5672, help='RabbitMQ server port'),
-    cfg.StrOpt('rabbit_virtual_host', default='/',
-               help='RabbitMQ server virtual host name'),
-    cfg.StrOpt('rabbit_task_queue', default='tasks',
-               help='RabbitMQ tasks queue name'),
-    cfg.StrOpt('rabbit_user', default='guest', help='RabbitMQ user'),
-    cfg.StrOpt('rabbit_password', default='guest', help='RabbitMQ password')
+    # TODO(everyone): add DB properties.
 ]
 
 use_debugger = cfg.BoolOpt(
@@ -86,13 +79,19 @@ executor_opts = [
                help='The version of the executor.')
 ]
 
-launch_opt = cfg.StrOpt(
+launch_opt = cfg.ListOpt(
     'server',
-    default='all',
-    choices=('all', 'api', 'engine', 'executor'),
-    help='Specifies which mistral server to start by the launch script.'
+    default=['all'],
+    help='Specifies which mistral server to start by the launch script. '
+         'Valid options are all or any combination of '
+         'api, engine, and executor.'
 )
 
+action_plugins_opt = cfg.ListOpt(
+    'action_plugins',
+    default=['mistral.actions.std'],
+    help='List of namespaces to search for plug-ins.')
+
 
 wf_trace_log_name_opt = cfg.StrOpt('workflow_trace_log_name',
                                    default='workflow_trace',
@@ -104,11 +103,10 @@ CONF = cfg.CONF
 CONF.register_opts(api_opts, group='api')
 CONF.register_opts(engine_opts, group='engine')
 CONF.register_opts(pecan_opts, group='pecan')
-CONF.register_opts(auth_token.opts, group='keystone')
 CONF.register_opts(db_opts, group='database')
-CONF.register_opts(rabbit_opts, group='rabbit')
 CONF.register_opts(executor_opts, group='executor')
 CONF.register_opt(wf_trace_log_name_opt)
+CONF.register_opt(action_plugins_opt)
 
 CONF.register_cli_opt(use_debugger)
 CONF.register_cli_opt(launch_opt)
@@ -123,9 +121,23 @@ CONF.import_opt('log_date_format', 'mistral.openstack.common.log')
 CONF.import_opt('use_syslog', 'mistral.openstack.common.log')
 CONF.import_opt('syslog_log_facility', 'mistral.openstack.common.log')
 
+# Extend oslo default_log_levels to include some that are useful for mistral
+# some are in oslo logging already, this is just making sure it stays this
+# way.
+default_log_levels = cfg.CONF.default_log_levels
+logs_to_quieten = ['sqlalchemy=WARN',
+                   'oslo.messaging=INFO',
+                   'iso8601=WARN',
+                   'eventlet.wsgi.server=WARN',
+                   'stevedore=INFO',
+                   'mistral.openstack.common.loopingcall=INFO',
+                   'mistral.openstack.common.periodic_task=INFO',
+                   'mistral.services.periodic=INFO']
+for chatty in logs_to_quieten:
+    if chatty not in default_log_levels:
+        default_log_levels.append(chatty)
 cfg.set_defaults(log.log_opts,
-                 default_log_levels=['sqlalchemy=WARN',
-                                     'eventlet.wsgi.server=WARN'])
+                 default_log_levels=default_log_levels)
 
 
 def parse_args(args=None, usage=None, default_config_files=None):
