@@ -14,23 +14,24 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-from pecan.hooks import PecanHook
-
 import eventlet
+from oslo import messaging
+from pecan import hooks
 
+from mistral import exceptions as exc
+from mistral.openstack.common import jsonutils
 from mistral.openstack.common import log as logging
 from mistral import utils
-from mistral import exceptions as exc
 
 LOG = logging.getLogger(__name__)
 
-#TODO(rakhmerov): refactor all threadlocal things with mistral.utils
+# TODO(rakhmerov): refactor all threadlocal things with mistral.utils
 
 _CTX_THREAD_LOCAL_NAME = "MISTRAL_APP_CTX_THREAD_LOCAL"
 
 
 class BaseContext(object):
-    """Container for context variables"""
+    """Container for context variables."""
 
     _elements = set()
 
@@ -124,9 +125,39 @@ def context_from_headers(headers):
     )
 
 
-class ContextHook(PecanHook):
+class JsonPayloadSerializer(messaging.NoOpSerializer):
+    @staticmethod
+    def serialize_entity(context, entity):
+        return jsonutils.to_primitive(entity, convert_instances=True)
+
+
+class RpcContextSerializer(messaging.Serializer):
+
+    def __init__(self, base=None):
+        self._base = base or messaging.NoOpSerializer()
+
+    def serialize_entity(self, context, entity):
+        if not self._base:
+            return entity
+        return self._base.serialize_entity(context, entity)
+
+    def deserialize_entity(self, context, entity):
+        if not self._base:
+            return entity
+        return self._base.deserialize_entity(context, entity)
+
+    def serialize_context(self, context):
+        return context.to_dict()
+
+    def deserialize_context(self, context):
+        ctx = MistralContext(**context)
+        set_ctx(ctx)
+        return ctx
+
+
+class ContextHook(hooks.PecanHook):
     def before(self, state):
-        request_ctx = context_from_headers(state.request.headers).to_dict()
+        request_ctx = context_from_headers(state.request.headers)
         set_ctx(request_ctx)
 
     def after(self, state):
